let insertItem = function (item) {
    if (item.type == undefined || item.category == undefined || item.name == undefined)
        return;
    let outer = document.createElement('div');
    outer.className = "post-preview db-item";
    outer.dataset.cat = item.type;
    outer.dataset.subcat = item.category;
    outer.dataset.search = item.name.toLowerCase() + ' ' + item.description.toLowerCase();

    let searchDesc = document.createElement('div');
    searchDesc.innerHTML = item.description.toLowerCase();
    searchDesc.style.display = 'none';

    let inner = document.createElement('a');
    if (item.location != undefined && item.location != null) {
        inner.href = item.location;
    } else {
        inner.href = '#';
    }
    inner.target = "_blank";

    let header = document.createElement('h2');
    header.innerHTML = item.name;
    header.className = "post-title";

    let desc = document.createElement('h3');
    desc.innerHTML = item.description;
    desc.className = "post-subtitle";

    if (item.imgUrl != undefined && item.imgUrl != null) {
        if (item.imgUrl.length > 3) {
            let i = document.createElement('img');
            i.alt = 'image';
            if (item.imgUrl.startsWith('http:')) {
                i.src = 'https:' + item.imgUrl.substring(5);
            } else {
                i.src = item.imgUrl;
            }
            i.style.maxWidth = "200px";
            i.style.display = "inline";
            i.style.borderRadius = '15px';
            inner.appendChild(i);
        }
    }

    inner.appendChild(header);

    if (item.author != undefined && item.author != null) {
        if (item.imgUrl.length > 1) {
            let h6 = document.createElement('h6');
            h6.innerHTML = "By " + item.author;
            inner.appendChild(h6);
        }
    }

    inner.appendChild(desc);

    let hr = document.createElement('hr');

    outer.appendChild(inner);
    outer.appendChild(hr)

    document.getElementById('db-items').appendChild(outer);
};

let makeMenu = function (name, set) {
    let catName = "db-cat-" + name.split(' ').join('-');

    let li = document.createElement('li');
    let navClick = document.createElement('a');
    navClick.href = '#' + catName;
    navClick.className = "btn btn-primary catNav";
    navClick.dataset.toggle = "pill";
    navClick.innerHTML = name;

    let nav = document.getElementById('db-cats');

    li.appendChild(navClick);
    nav.appendChild(li);

    //<li><a data-toggle="pill" href="#db-cat-parts" class="btn btn-primary">3D Printed Parts</a></li>

    var makeSubcat = function (subcat) {
        let li = document.createElement('li');
        li.style.width = "100%";
        let btn = document.createElement('button');
        btn.className = "btn btn-primary subcatNav";
        btn.style.width = "100%";
        btn.innerHTML = subcat;
        li.appendChild(btn);
        return li;
    }
    let dv = document.createElement('div');
    dv.id = catName;
    dv.className = "tab-pane fade";
    dv.style.borderTopColor = "#FFF";
    dv.style.borderTopStyle = "solid";
    dv.style.borderTopWidth = "2px";
    let ul = document.createElement('ul');
    ul.className = 'nav nav-pills';

    for (let i of set) {
        ul.appendChild(makeSubcat(i));
    }
    dv.appendChild(ul);
    document.getElementById('db-subcats').appendChild(dv);
};

let handleItems = function (items) {
    let total = new Set();
    let obj = {};
    for (let i = 0; i < items.length; i++) {
        total.add(items[i].type);
        if (obj[items[i].type] == undefined) {
            obj[items[i].type] = new Set();
        }
        obj[items[i].type].add(items[i].category);
        insertItem(items[i]);
    }
    console.log(obj);
    for (let k in obj) {
        makeMenu(k, obj[k]);
    }
};

let loadDatabase = function (results) {
    handleItems(results);
    setTimeout(function () {
        $(".catNav").click(function () {
            let cName = $(this).text();
            $(".db-item").hide();
            $("[data-cat='" + cName + "']").show();
        });

        $(".subcatNav").click(function () {
            let cName = $(this).text();
            $(".db-item").hide();
            $("[data-subcat='" + cName + "']").show();
        });

        $("#db-item-search").keyup(function () {
            var selectSize = $(this).val();
            searchFilter(selectSize);
        });
        function searchFilter(e) {
            var regex = new RegExp('\\b\\w*' + e + '\\w*\\b');
            $('.db-item').hide().filter(function () {
                return regex.test($(this).data('search'));
            }).show();
        }
        $("#db-item-search").show();
    }, 2000);
};





$(function () {
    if (location.protocol != 'https:')
    {
        if (location.protocol != 'file:') {
            location.href = 'https:' + window.location.href.substring(window.location.protocol.length);
        } else {
            console.log("Running offline fallback...");
            let din = document.createElement('div');
            let txt = document.createElement('h3');
            let fin = document.createElement('input');
            fin.type = 'file';
            fin.accept = '.csv';
            txt.innerHTML = "Please Load the Database csv file";
            din.appendChild(txt);
            din.appendChild(fin);

            document.getElementById('ms').appendChild(din);
            $('#db-subcats').hide();
            fin.addEventListener('change', function () {
                Papa.parse(fin.files[0], {
                    header: true,
                    complete: function (results) {
                        $('#db-subcats').show();
                        loadDatabase(results.data);
                        din.style.display = 'None';
                    }
                });
            });
        }
    } else {
        Papa.parse("Compendium.csv?104", {
            download: true,
            header: true,
            complete: function (results) {
                loadDatabase(results.data);
            }
        });
    }
}
);